services_views.service("$mainView", ["$manager", "$auth", "$action", "$location", "$mainLang", "$rootScope", 
					"$dialogView", "$longtabView", "$heighter", "$demon", "$way", 
					function($manager, $auth, $action, $location, $mainLang, $rootScope, 
						$dialogView, $longtabView, $heighter, $demon, $way){

	var self = this;
	var swipe = null;
	var curScrollTop = 0;
	var isNewPosts = true;	// don't check new posts while cur posts loading

	this.isUpdating = false;
	
	this.initSwipe = function(){
		var appElement = document.querySelector('[ng-controller=mainCtrl]');
		var $scope = angular.element(appElement).scope();

		var mainWrap = document.getElementById("mainWrap");
		swipe = new Swiper(mainWrap, Swiper.SELF, Swiper.screenHeight, "y", Swiper.BOT, 15, 0, function(type){
			switch(type){
				case Swiper.START:
					break;
				case Swiper.GOAL:
					$(".main-update-block").removeClass("none");
					break;
				case Swiper.ENABLE_END:
					if(!self.isUpdating){
						self.isUpdating = true;

						$(".main-update-block").css("position", "relative");
						$(".main-update-image").addClass("rotating");						
						$auth.update($scope);
					}
					break;
				case Swiper.DISABLE_END:
					$(".main-update-block").css("position", "absolute");
					$(".main-update-image").removeClass("rotating");
					$(".main-update-block").addClass("none");
					break;
			}
		});
		swipe.setIsActive(true);
	}
	
	this.updateEnd = function(){
		self.isUpdating = false;
		setTimeout(function(){
			$(".main-update-block").css("position", "absolute");
			$(".main-update-image").removeClass("rotating");
			$(".main-update-block").addClass("none");
			swipe.goStartPos();
		}, 250);
	}

	this.manageView = function($scope, response){
		if(response.status == Constant.OK_STATUS){
			this.okView($scope, response);
		}else{
			this.errView($scope, response);
		}
		$scope.$applyAsync();
	}
	
	this.okView = function($scope, response){
		switch(response.action){
			case "update":
				this.updateOk($scope, response);
				break;
			case "moreFields":
				this.moreFieldsOk($scope, response);
				break;
		}
	}
	
	this.errView = function($scope, response){
		switch(response.action){
			case "update":
				this.updateErr($scope, response);
				break;
			case "moreFields":
				this.moreFieldsErr($scope, response);
				break;
		}
	}
	
	this.moreFieldsOk = function($scope, response){
		$scope.posts = $manager.instance.getUser().getPosts();
		// send posts to longtab view
		$longtabView.putPosts($scope.posts);

		newPostsLoad(false);
	}
	
	this.moreFieldsErr = function($scope, response){
		newPostsLoad(false);
		switch(response.data.errorCode){
			case Constant.ERR_CODE_BROWSER_UPDATE:
				$dialogView.showToast($dialogView.strings.readErr);
				break;
			case Constant.ERR_CODE_CONNECTOR_CONNECTION:
				$dialogView.showToast($dialogView.strings.connectErr);
				break;
		}
	}
	
	this.updateOk = function($scope, response){
		this.setInfo($scope, response.data);
		this.updateEnd();
	}
	
	this.updateErr = function($scope, response){
		this.updateEnd();
		switch(response.data.errorCode){
			case Constant.ERR_CODE_BROWSER_UPDATE:
				$dialogView.showToast($dialogView.strings.readErr);
				break;
			case Constant.ERR_CODE_CONNECTOR_UPDATE:
				$dialogView.showToast($dialogView.strings.connectErr);
				break;
			case Constant.ERR_CODE_CONNECTOR_CONNECTION:
				$dialogView.showToast($dialogView.strings.connectErr);
				break;
		}
	}

	this.moveAutoTask = function(){
		$location.path("/autotask");
	}
	
	this.setInfo = function($scope, data){
		var user = $manager.instance.getUser();
		// set num of subscribers
		$scope.followersCount = user.getFollowedCount();
		// set num of you subscribe
		$scope.followingCount = user.getFollowsCount();
		// set num of posts
		$scope.postsCount = user.getPostsCount();
		// set posts
		$scope.posts = user.getPosts();
		// send posts to longtab view
		$longtabView.putPosts($scope.posts);
		// show noposts image if has no posts
		if($scope.posts.length == 0){
			$(".main-notasks-block").removeClass("none");
		}

		// set user's level
		$scope.userLvl = user.getXpInfo().getLvl();
		// set user's expirience
		$scope.lvlProgress = ((user.getXpInfo().getXp() * 100) / 1000) + "%";
		// set user's avatar
		$rootScope.profileAvatar = user.getProfileAvatar();
		// set user's nickname
		$rootScope.nick = user.getNick();

		// set user's achievements
		this.setUserFeatures($scope, user, data);
		// set user's deposit
		$dialogView.setCash(user.getCash());
	}
	
	// set premium and turbo icons and achivements on main page
	this.setUserFeatures = function($scope, user, data){
		var premium = {};
		var turbo = {};
		var mass = [];
		
		// set premium icon
		if(+data.premium)
			premium.src = "images/premium.png";
		else
			premium.src = "images/premium_none.png";
		premium.href = '#/donate/premium';
		mass.push(premium);

		// set turbo icon
		switch(+data.turbo){
			case 0:
				turbo.src = "images/turbo_none.png";
				break;
			case 1:
			case 4:
				turbo.src = "images/turbo_1.png";
				break;
			case 2:
				turbo.src = "images/turbo_2.png";
				break;
			case 3:
				turbo.src = "images/turbo_3.png";
				break;
			case 5:
				turbo.src = "images/turbo_4.png";
				break;
			default:
				turbo.src = "images/turbo_none.png";
		}

		turbo.href = '#/donate/turbo';
		mass.push(turbo);

		var achieves = user.getAchieves();
		for(var i=0; i<achieves.length; i++){
			var achieve = {};
			achieve.src = "images/achieves/" + achieves[i] +".png";
			achieve.href = 'javascript:void(0)';
			mass.push(achieve);
		}
		if(typeof $scope !== "undefined"){
			$scope.achieves = mass;
		}
	}

	// set every post and set anim to it
	this.setPosts = function(index, src){
		$(".main-info .quest-block .quest-elem-block").eq(index).css("background-image", "url(" + src + ")");

		var height = (window.innerWidth * 32 / 100) + "px";
		$(".main-info .quest-block .quest-elem-block").eq(index).css("line-height", height);
		$(".main-info .quest-block .quest-elem-block").eq(index).css("height", height);

		if(index % 3 == 0){
			$(".main-info .quest-block .quest-elem-block").eq(index).css("float", "left");
		}else if(index % 3 == 2){
			$(".main-info .quest-block .quest-elem-block").eq(index).css("float", "right");
		}else{
			$(".main-info .quest-block .quest-elem-block").eq(index).css("float", "left");
			$(".main-info .quest-block .quest-elem-block").eq(index).css("margin-left", "2%");
		}
		$(".main-info .quest-block .quest-elem-block").eq(index).removeClass("none");
	}

	function initScroll(){
		document.querySelector(".main-content").addEventListener("scroll", function(){
			if($(".main-content").scrollTop() == 0){
				swipe.setIsActive(true);
			}else{
				swipe.setIsActive(false);
			}
			// hide earn but while scrooling
			hideShowEarnBut();
			// check new posts
			checkNewPosts();
		});
	}

	function hideShowEarnBut(){
		if($(".main-content").scrollTop() > curScrollTop){
			$(".goearn-but-block").css("display", "none");
			curScrollTop = $(".main-content").scrollTop();
		}
		if($(".main-content").scrollTop() < curScrollTop){
			$(".goearn-but-block").css("display", "inline");
			curScrollTop = $(".main-content").scrollTop();
		}
	}

	function checkNewPosts(){
		var contentSize = $heighter.setHeight(Constant.MAJOR_VIEW);

		if(($(".main-content").scrollTop() + contentSize) >= ($(".main-info").height() - 5)){
			if($manager.instance.getUser().hasMorePosts() && isNewPosts){
				newPostsLoad(true);

				var appElement = document.querySelector('[ng-controller=mainCtrl]');
				var $scope = angular.element(appElement).scope();
				$action.moreFields($manager.instance.getUser(), $scope);
			}
		}
	}

	// show or hide loading new images in "show more" button
	function newPostsLoad(type){
		if(type){
			$(".main-more-block:first").removeClass("none");
			// scroll to bottom
			$(".main-content").scrollTop($(".main-info").height());
			isNewPosts = false;
		}else{
			// minus loadlock height for scroll
			curScrollTop -= $(".main-more-block:first").outerHeight(true);
			$(".main-more-block:first").addClass("none");
			isNewPosts = true;
		}
	}

	function setContentSize(){
		$(".main-content").css("height", $heighter.setHeight(Constant.MAJOR_VIEW));
	}

	//init all functions in view
	this.initViewParams = function(){
		// show go to earn button
		$(".goearn-but-block").css("display", "inline");
		$(".goearn-but-block").removeClass("goearn-but-bottom");

		// show navigation bar
		$(".navigation").removeClass("none");

		
		// set height of main content
		setContentSize();

		// init content scroll
		initScroll();

	}
}]);