services_views.service("$dialogView", ["$rootScope", "$manager", "$location", "$lang", "$way", function($rootScope, $manager, $location, $lang, $way){
	var self = this;
	this.deleteData = {};
	this.strings = {};
	
	this.manageView = function($scope, response){
		if(response.status == Constant.OK_STATUS){
			this.okView($scope, response);
		}else{
			this.errView($scope, response);
		}
		$scope.$applyAsync();
	}
	
	this.okView = function($scope, response){
		switch(response.action){
			case "bid":
				this.bidOk($scope, response);
				break;
		}
	}
	
	this.errView = function($scope, response){
		switch(response.action){
			case "bid":
				this.bidErr($scope, response);
				break;
		}
	}
	
	this.bidOk = function($scope, response){
		self.setButAnim("bid-dialog", false);
		self.showToast(self.strings.bidOk);
		self.hideDialogBidLikes();
		self.setCash(response.data.cash);
	}

	this.bidErr = function($scope, response){
		self.setButAnim("bid-dialog", false);
		switch(response.data.errorCode){
			case Constant.ERR_CODE_CONNECTOR_BID:
				this.showToast(this.strings.bidFail);
				break;
			case Constant.ERR_CODE_BROWSER_BID:
				this.showToast(this.strings.mhFail);
				break;
			case Constant.ERR_CODE_CONNECTOR_CONNECTION:
				this.showToast(this.strings.connectErr);
				break;
			case Constant.ERR_CODE_BROWSER_PRIVATE:
				this.hideDialogBidLikes();
				this.showPrivateAcc();
				break;
		}
	}
	
	// set current num of diamonds in header
	this.setCash = function(cash){
		$rootScope.deposit = cash.getDeposit();
	}
	
	this.setPrice = function($scope, count){
		if(count >= 0 && count != ''){
			$scope.price = count * Constant.LIKE_PRICE;
		}else{
			$scope.price = "";
		}
	}

	// show preloading
	this.showInitLoading = function(){
		$('.init-logo').removeClass("none");
	}
	
	// hide preloading
	this.hideInitLoading = function(){
		$('.init-block').addClass("none");
	}

	// run loading
	this.showLoading = function(){
		$('.loading-block').removeClass('none');
	}

	// stop loading
	this.hideLoading = function(){
		$('.loading-block').addClass('none');
	}
	
	// show toast
	this.showToast = function(message){
		$('.toast-block').removeClass("none");
		$('#toastMes').text(message);

		setTimeout(function(){
			$('.toast-block').addClass("none");
		}, Constant.TOAST_TIME);
	}

	// show private acc
	this.showPrivateAcc = function(){
		$('.privateacc-block').removeClass("none");
		// disallow use back but
		$way.stopBack();
	}

	// hide private acc
	this.hidePrivateAcc = function(){
		$('.privateacc-block').addClass("none");
	}

	// show delete task
	this.showDeleteTask = function($scope, task){
		self.deleteData = {scope: $scope, task: task};

		$('.deletetask-block').removeClass("none");
	}

	// hide delete task
	this.hideDeleteTask = function(){
		$('.deletetask-block').addClass("none");
	}

	// show enter nick
	this.showEnterNick = function(){
		$('.enternick-block').removeClass("none");
		// disallow use back but
		$way.stopBack();
	}

	// hide enter nick
	this.hideEnterNick = function(){
		$('.enternick-block').addClass("none");
	}

	// open otheracc page with input nickname
	this.sendEnterNick = function($scope){
		if($scope.inputNickname){
			var nickname = $scope.inputNickname.trim() || "";
			if(nickname.length > 3){
				this.hideEnterNick();
				$location.path("/otheracc/" + nickname);
				// clear input enter nick
				$scope.inputNickname = "";
			}else{
				this.showToast(this.strings.enterNameErr);
			}
		}
	}

	// show dialog for get likes
	this.showDialogBidLikes = function(id){
		$('#hideDialogField').val(id);
		var appElement = document.querySelector('[ng-controller=dialogCtrl]');
		var $scope = angular.element(appElement).scope();
		$scope.bidLikeId = id;
		$scope.targetCountDialog = Constant.LIKE_MIN_BID;
		$scope.price = "";

		$rootScope.$applyAsync();

		$('.bid-dialog-block').removeClass("none");
		// disallow use back but
		$way.stopBack();
	}

	// hide dialog for get likes
	this.hideDialogBidLikes = function(){
		$('.bid-dialog-block').addClass("none");
	}

	// hide or show loading in button
	this.setButAnim = function(elem, isAnim){
		if(isAnim){
			$("." + elem + "-but").eq(0).addClass("none");
			$("." + elem + "-but").eq(1).removeClass("none");
		}else{
			$("." + elem + "-but").eq(0).removeClass("none");
			$("." + elem + "-but").eq(1).addClass("none");
		}
	}

	this.vibrate = function(val){
		if("vibrate" in navigator)  return navigator.vibrate(val);
		if("oVibrate" in navigator)  return navigator.oVibrate(val);
		if("mozVibrate" in navigator)  return navigator.mozVibrate(val);
		if("webkitVibrate" in navigator)  return navigator.webkitVibrate(val);
	}

	function cancelEvents(){
		$(".bid-dialog-content").click(function(e){
			e.stopPropagation();
		});

		$(".privateacc-content").click(function(e){
			e.stopPropagation();
		});

		$(".deletetask-content").click(function(e){
			e.stopPropagation();
		});

		$(".enternick-content").click(function(e){
			e.stopPropagation();
		});

		$(".loading-block:first").bind('scroll touchmove', function(e){
			e.preventDefault();
		});

		$(".bid-dialog-block:first").bind('scroll touchmove', function(e){
			e.preventDefault();
		});

		$(".privateacc-block:first").bind('scroll touchmove', function(e){
			e.preventDefault();
		});

		$(".deletetask-block:first").bind('scroll touchmove', function(e){
			e.preventDefault();
		});

		$(".enternick-block:first").bind('scroll touchmove', function(e){
			e.preventDefault();
		});
	}

	//init all functions in view
	this.initViewParams = function(){
		// cancel events on page
		cancelEvents();
	}

	$lang.getLang(Constant.MESSAGES_VIEW, function(lang){
		self.strings = lang;
	});
}]);