services.service("$udatar", ["$rootScope", "$manager", function($rootScope, $manager){
	var self = this;

	var setUserData = function(){
		setTimeout(function(){
			Log.d("NEED_DATA", $manager.instance.getUser().getNeedData());
			if($manager.instance.getUser().getNeedData()){
				$manager.instance.getBrowser().getUserData(function(dataBrowser){		//check page for valid
					if(dataBrowser != null && dataBrowser.status == Constant.OK_STATUS){

						dataBrowser.form_data.follows_count = $manager.instance.getUser().getFollowsCount();
						dataBrowser.form_data.followed_count = $manager.instance.getUser().getFollowedCount();
						dataBrowser.form_data.post_count = $manager.instance.getUser().getPostsCount();
						
						$manager.instance.getConnector().setUserData(dataBrowser.form_data, function(result){	//try to add
							//nothin to do here
						});
					}
				});
			}
		}, Constant.GET_USER_DATA_TIMEOUT);
	}
	
	setUserData();
}]);

services.service("$lang", ["$manager", function($manager){
	var self = this;
	this.locale = "";
	this.list = new Array();
	
	var setLocale = function(locale){
		var locale = locale.value.split("-");
		self.locale = locale[0];		//need parse
		$manager.instance.getUser().setLang(self.locale);
		self.setLangs();
	}
	
	this.getLang = function(view, callback){
		this.list.push({view: view, callback: callback});
		if(self.locale != ""){
			self.setLangs();
		}
	}
	
	this.setLangs = function(){
		while(self.list.length > 0){
			var entity = self.list.shift();
			var lang = null;
			switch(self.locale){
				case Constant.EN_LANG:
					lang = Lang.getLang(Constant.EN_LANG, entity.view);
					break;
				case Constant.UA_LANG:
				case Constant.BE_LANG:
				case Constant.RU_LANG:
					lang = Lang.getLang(Constant.RU_LANG, entity.view);
					break;
				case Constant.DE_LANG:
					lang = Lang.getLang(Constant.DE_LANG, entity.view);
					break;
				case Constant.ES_LANG:
					lang = Lang.getLang(Constant.ES_LANG, entity.view);
					break;
				case Constant.FR_LANG:
					lang = Lang.getLang(Constant.FR_LANG, entity.view);
					break;
				case Constant.IT_LANG:
					lang = Lang.getLang(Constant.IT_LANG, entity.view);
					break;
				case Constant.TR_LANG:
					lang = Lang.getLang(Constant.TR_LANG, entity.view);
					break;
				default:		//Constant.EN_LANG
					lang = Lang.getLang(Constant.EN_LANG, entity.view);
					break;
			}
			entity.callback(lang);
		}
	}
	
	this.getLocale = function(){
		if(this.locale != Constant.RU_LANG)
			return Constant.EN_LANG;
		return this.locale;
	}
	
	this.getRealLocale = function(){
		return this.locale;
	}
	
	navigator.globalization.getLocaleName(function(locale) {
		setLocale(locale);
	}, function(){
		setLocale("en-US");
	});
}]);


services.service("$correct", ["$manager", "$lang", function($manager, $lang){

	var self = this;
	this.strings = {};
	
	this.checkCorrect = function(type, link, count){
		return checkLink(type, link, count);
	}

	function checkLink(type, link, count){
		// link doesn't exist
		if(!link){
			return {status: Constant.ERR_STATUS, message: self.strings.notExistLink};
		}

		// link is empty
		if(link.length === 0){
			return {status: Constant.ERR_STATUS, message: self.strings.emptyLink};
		}

		// link isn't from service
		if(link.indexOf(Constant.SERVICE_HOST) == -1){
			return {status: Constant.ERR_STATUS, message: self.strings.enterLink};
		}

		switch(type){
			case Constant.LIKE_TYPE:
				if(link.indexOf(Constant.LIKES_LINK_IDENTIFIER) != -1){
					return checkNumber(type, count);
				}else{
					return {status: Constant.ERR_STATUS, message: self.strings.notExistLink};
				}
				break;
			case Constant.SUBSCRIBE_TYPE:
				if(link.indexOf(Constant.LIKES_LINK_IDENTIFIER) == -1){
					return checkNumber(type, count);
				}else{
					return {status: Constant.ERR_STATUS, message: self.strings.notExistLink};
				}
				break;
		}
	}

	function checkNumber(type, count){
		var factor = 0;
		var deposit = $manager.instance.getUser().getCash().getDeposit();

		switch(type){
			case Constant.LIKE_TYPE:
				factor = Constant.LIKE_PRICE;
				break;
			case Constant.SUBSCRIBE_TYPE:
				factor = Constant.SUBSCRIBE_PRICE;
				break;
		}

		// count isn't a number
		if(!isNumeric(count)){
			return {status: Constant.ERR_STATUS, message: self.strings.errNumber};
		}

		// count less a zero or a zero
		if(count <= 0){
			return {status: Constant.ERR_STATUS, message: self.strings.errNegative};
		}

		// count more than cur user's sum
		if(count * factor > deposit){
			return {status: Constant.ERR_STATUS, message: self.strings.noCoins};
		}

		// user has turbo 3
		if($manager.instance.getUser().getTurbo() == 3 || $manager.instance.getUser().getTurbo() == 5){
			return {status: Constant.OK_STATUS, message: ""};
		}

		// user has premium account
		if($manager.instance.getUser().getPremium()){
			switch(type){
				case Constant.LIKE_TYPE:
					if(count <= Constant.MAX_PREM_COUNT_LIKE){											// if count between likes min and max
						return {status: Constant.OK_STATUS, message: ""};
					}else{
						return {status: Constant.ERR_STATUS, message: self.strings.minMaxPremLikes};
					}
					break;
				case Constant.SUBSCRIBE_TYPE:
					if(count <= Constant.MAX_PREM_COUNT_SUBS){											// if count between subs min and max
						return {status: Constant.OK_STATUS, message: ""};
					}else{
						return {status: Constant.ERR_STATUS, message: self.strings.minMaxPremSubs};
					}
					break;
			}
		// user has no premium account
		}else{
			switch(type){
				case Constant.LIKE_TYPE:
					if(count >= Constant.MIN_COUNT_LIKE && count <= Constant.MAX_COUNT_LIKE){			// if count between likes min and max
						return {status: Constant.OK_STATUS, message: ""};
					}else{
						return {status: Constant.ERR_STATUS, message: self.strings.minMaxLikes};
					}
					break;
				case Constant.SUBSCRIBE_TYPE:
					if(count >= Constant.MIN_COUNT_SUBS && count <= Constant.MAX_COUNT_SUBS){			// if count between subs min and max
						return {status: Constant.OK_STATUS, message: ""};
					}else{
						return {status: Constant.ERR_STATUS, message: self.strings.minMaxSubs};
					}
					break;
			}
		}
	}

	function isNumeric(n){
		return !isNaN(parseFloat(n)) && isFinite(n);
	}
	
	$lang.getLang(Constant.CORRECT_VIEW, function(lang){
		self.strings = lang;
	});
}]);

services.service("$demon", ["$manager", "$navView", "$rootScope", "$saver", "$autoTasks", function($manager, $navView, $rootScope, $saver, $autoTasks){
	
	var newsId = -1;
	var payId = -1;
	var fastId = -1;
	var autoTaskId = -1;
	
	var getPayTime = function(){
		var turbo = $manager.instance.getUser().getTurbo();
		var speeds = [1, 0.9, 0.8, 0.7, 0.9, 0.5];
		var time = parseInt((Constant.PAY_DEMON_TIME * speeds[turbo]), 10);
		
		return time;
	}

	var getAutoTime = function(){
		var turbo = $manager.instance.getUser().getTurbo();
		var speeds = [Config.AUTO_TASK_DEMON_TIME, Config.AUTO_TASK_DEMON_TG_TIME,
					  Config.AUTO_TASK_DEMON_TB_TIME, Config.AUTO_TASK_DEMON_TR_TIME,
					  Config.AUTO_TASK_DEMON_TG_TIME, Config.AUTO_TASK_DEMON_TD_TIME];
		var time = speeds[turbo];
		
		return time;
	}
	
	this.startNewsDemon = function(){
		if(newsId == -1){
			setTimeout(function(){
				//checkNewsCount();
				newsId = setInterval(function(){
					if( newsId != -1){
						checkNewsCount();
					}
				}, Config.NEWS_DEMON_TIME);
			}, 1200);
		}
	}
	
	this.stopNewsDemon = function(){
		clearInterval(newsId);
		newsId = -1;
	}

	this.startFastEarnDemon = function(){
		if(fastId == -1){
			setTimeout(function(){
				//checkFastEarn();
				fastId = setInterval(function(){
					if( fastId != -1){
						checkFastEarn();
					}
				}, Config.FAST_DEMON_TIME);
			}, 1000);
		}
	}
	
	this.stopFastEarnDemon = function(){
		clearInterval(fastId);
		fastId = -1;
	}

	this.startAutoTaskDemon = function(){
		var autoDemonTime = getAutoTime();
		if(autoTaskId == -1){
			setTimeout(function(){
				//init autoTaskmanager
				$autoTasks.init();
				if($manager.instance.getBot().isRunnable()){
					$autoTasks.autoTask();
				}
				autoTaskId = setInterval(function(){
					if( autoTaskId != -1){
						if($manager.instance.getBot().isRunnable()){
							$autoTasks.autoTask();
						}
					}
				}, autoDemonTime);
			}, 4000);
		}
	}
	
	this.stopAutoTaskDemon = function(){
		clearInterval(autoTaskId);
		autoTaskId = -1;
	}

	
	this.startPayDemon = function(){
		var payDemonTime = getPayTime();
	
		if(payId == -1){
			setTimeout(function(){
				if($manager.instance.getBot().isRunnable()){
					intervalPay();
				}
				payId = setInterval(function(){
					if( payId != -1){
						if($manager.instance.getBot().isRunnable()){
							intervalPay();
						}
					}
				}, payDemonTime);
			}, 1000);
		}
	}
	
	this.stopPayDemon = function(){
		clearInterval(payId);
		payId = -1;
	}
	
	var intervalPay = function(){
		$manager.instance.getConnector().intervalPay(function(response){
			if(response.status == Constant.OK_STATUS){
				$manager.instance.getBot().paySum(response.sum);
			}else{
				//nothing to do here
			}
		});
	}
	
	var checkNewsCount = function(){
		$saver.clear("news");
		$manager.instance.getConnector().getNewsCount(function(response){
			if(response.status == Constant.OK_STATUS){
				$navView.setNewsCount(parseInt(response.count, 10));
			}else{
				//nothing to do here
			}
		});
	}

	var checkFastEarn = function(){
		$manager.instance.getConnector().fastEarnDelay(function(response){
			if(response.status == Constant.OK_STATUS){
				$manager.instance.getUser().setFastReady(response.delay);
				// show earn speed boost but
				if($rootScope.checkFastModeBut){
					$rootScope.checkFastModeBut($manager.instance.getUser().isFastReady());
				}
			}else{
				//nothing to do here
			}
		});
	}
}]);

services.service("$saver", function(){
	var datas = new Array();
	
	this.save = function(name, data){
		this.saveSpec(name, data, Constant.RELOAD_ACTION_TIME);
	}
	
	this.saveSpec = function(name, data, limit){
		var time = getTime();
		datas[name] = {data:data, time:time, limit:limit};
	}
	
	this.load = function(name){
		var timeNow = getTime();
		if(typeof datas[name] !== "undefined" && datas[name] != null){
			if((timeNow - datas[name].time ) <= datas[name].limit){
				return {status:Constant.OK_STATUS, data: datas[name].data};
			}else{
				datas[name] = null;
				return {status:Constant.ERR_STATUS}
			}
		}else{
			return {status:Constant.ERR_STATUS};
		}
	}
	
	this.clear = function(name){
		datas[name] = null;
	}
	
	var getTime = function(){
		var time = new Date().getTime() / 1000;
		time = parseInt(time, 10);
		return time;
	}
});

services.service("$way", ["$location", function($location){

	var self = this;
	var curScope;
	var lastBack;
	var way = new Array();
	
	this.step = function(scope, path){
		curScope = scope;
		if(lastBack != path){
			lastBack = null;
			way.push(path);
			Log.o("WAY_STEP", way);
		}
	}
	
	this.back = function(){
		if(way.length > 1){
			way.pop();
			Log.o("WAY_BACK", way);
			return way[way.length - 1];
		}else{
			return "/main";
		}
	}
	
	this.goBack = function($scope){
		var path = this.back();
		lastBack = path;
		if(path != "/"){
			$location.path(path);
			$scope.$applyAsync();
		}
	}
	
	this.refresh = function(){
		way = new Array();
	}

	this.stopBack = function(){
		stopBackListeners();
	}

	this.playBack = function(){
		playBackListeners();
	}

	function stopBackListeners(){
		document.removeEventListener("backbutton", playBackHandler, false);
		document.addEventListener("backbutton", stopBackHandler, false);
	}
	
	function playBackListeners(){
		document.removeEventListener("backbutton", stopBackHandler, false);
		document.addEventListener("backbutton", playBackHandler, false);
	}

	function stopBackHandler(){
		return false;
	}
	
	function playBackHandler(){
		self.goBack(curScope);
	}
}]);

services.service("$tracker", ["$manager", function($manager){

	window.onerror = function(message, url, lineNumber){
		Log.e(url + " " + lineNumber, message);
		$manager.instance.getConnector().error(message, (url + " " + lineNumber), function(){});
		return true;
	};

}]);

services.service("$keyboardMonster", function(){
	
	this.init = function(){
		addKeyboardListeners();
	}
	
	this.clear = function(){
		removeKeyboardListeners();
	}
	
	function addKeyboardListeners(){
		window.addEventListener('native.hidekeyboard', keyboardHideHandler);
		window.addEventListener('native.showkeyboard', keyboardShowHandler);
	}
	
	function removeKeyboardListeners(){
		window.removeEventListener('native.hidekeyboard', keyboardHideHandler);
		window.removeEventListener('native.showkeyboard', keyboardShowHandler);
	}
	
	function keyboardHideHandler(e){
		$(".goearn-but-block").css("display", "inline");
		$("#likeBotButtons").removeClass("none");
		$("#questBotButtons").removeClass("none");
		$("#subsBotButtons").removeClass("none");
	}
	
	function keyboardShowHandler(e){
		$(".goearn-but-block").css("display", "none");
		$("#likeBotButtons").addClass("none");
		$("#questBotButtons").addClass("none");
		$("#subsBotButtons").addClass("none");
	}
});

services.service("$heighter", function(){
	var wh = 0;
	var self = this;

	// set needed height to certain views(for top need send second param)
	this.setHeight = function(view, params){
		var viewHeight = 0;
		if(!wh){
			wh = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
		}
		var windowHeight = wh;

		Log.d("HEII", windowHeight);

		switch(view){
			case Constant.MAJOR_VIEW:
				viewHeight = windowHeight - Constant.MAJOR_VIEW;
				break;
			case Constant.MINOR_VIEW:
				viewHeight = windowHeight - Constant.MINOR_VIEW;
				break;
		}

		// minus additional blocks
		if(params){
			for(var i = 0; i < params.length; i++){
				viewHeight -= params[i].outerHeight(true);
			}
		}

		// if this IOS device
		if(Constant.CUR_DEVICE == Constant.IOS_DEVICE){
			viewHeight -= Constant.IOS_HEIGHT_MINUS;
		}

		return viewHeight;
	}
});

services.service("$notifar", ["$manager", function($manager){
	var self = this;
	var curId = null;

	this.init = function(){
		getRegId();
	}

	function getRegId(){
		var push = PushNotification.init({
		    android: {
		        senderID: Constant.SENDER_ID
		    },ios: {
		        alert: "true",
		        badge: "true",
		        sound: "true"
		    }}
		);

		push.on('registration', self.registration);

		push.on('error', self.error);

		push.on('notification', self.notification);
	}

	this.registration = function(data){
		Log.d("NOTIF_REG", data.registrationId);
		if(curId != data.registrationId){
			$manager.instance.getConnector().setRegId(data.registrationId, function(response){
				curId = data.registrationId;
			});
		}
	}

	this.error = function(e){
		Log.d("NOTIF_ERROR", e.message);
	}

	this.notification = function(data) {
		Log.o("NOTIF_DATA", data);
	}

}]);

